import { Document } from './Document.js';
import { Reference } from './Reference.js';
import Database from './Database.js';
declare type ref = Reference | Document | string;
export default class Transaction {
    private db;
    writes: any[];
    preconditions: any;
    constructor(db: Database);
    /**
     * Validates that the arguments are of the correct types,
     * and that the documents are valid for this transaction.
     * Lastly we will return reliable data about the document.
     * @private
     */
    private handleArguments;
    /**
     * Wraps batch get with additional functionality needed in transactions.
     * Transactions need to be atomic. So in order to know that the document
     * wasn't changed concurrently then we save the updateTime of each document.
     *
     * Later we tell the database to use that as a precondition for the write.
     * In other words, if the update time of a document changed, then abort
     * the transaction. However, if a document didn't exist, then we use that
     * as a precondition, telling the database that if it was created concurrently
     * then it should abort the operation.
     */
    get(refs: Array<Reference | string>): Promise<any>;
    /**
     * Adds a write operation to the transaction, will create a document if
     * it didn't exist before, and overwrite all fo the data if it did.
     */
    set(ref: ref, data: any): void;
    /**
     * Adds a write operation to the transaction, will create a document if
     * it didn't exist before, and merge the data if it does exist.
     */
    update(ref: ref, data: any): void;
    /**
     * Adds a delete operation to the transaction.
     */
    delete(ref: ref): void;
    /**
     * Commits the transaction.
     * Will throw if the transaction failed.
     */
    commit(): Promise<undefined>;
}
export {};
